function seq = fix_seq(seq)
%FIX_SEQ returns a nucleotide sequence with only ATCG symbols
%
%   SEQOUT=FIXSEQ(SEQ) returns a nucleotide sequence without any symbols 
%   different from A, T, C, G. 
%
%   Example:
%
%       seq = 'ACTGNSATK';
%       seq = fix_seq(seq)
%
%   See also SEQORFS, SEQSHOWORFS, REGEXP.

    data = regexpi(seq, '[^atcg]');
    for i=1:size(data, 2)
        bad_pos = data(i);
        lu = baselookup('CODE', seq(bad_pos));
        if(rand() < .5)
            seq(bad_pos) = lu(1);
        else
            seq(bad_pos) = lu(3);
        end
    end
